package Pcore::DBD::DDL::Pg;

use Pcore -class;

with qw[Pcore::DBD::DDL];

1;
__END__
=pod

=encoding utf8

=head1 NAME

Pcore::DBD::DDL::Pg

=head1 SYNOPSIS

=head1 DESCRIPTION

=cut
